@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import copy
 import inspect
 import json
 from multiprocessing import RLock
@@ -6,7 +7,9 @@ import os
 import sys
 import threading
 import time
+import turtle
 from loguru import logger
+from tabulate import tabulate
 
 #  时间输出格式为：2020-01-01 00:00:00
 logid = logger.add("run.log", 
@@ -381,6 +384,7 @@ class Dxr_UnSubscriber:
 
 # 定义一个猴子补丁，用来替换原来的print函数
 def monky_print(*args, **kwargs):
+    tmp_args = copy.deepcopy(args)
     # 获取所在文件名和行号
     file_name = inspect.stack()[1].filename
     # 只取文件名
@@ -397,13 +401,30 @@ def monky_print(*args, **kwargs):
             isException = True
             break
     if isException:
-        logger.opt(colors=True).exception(f'<yellow>{file_name}:{line}</yellow>(<blue>{thread_name}:{thread_count}</blue>) {args}')
+        logger.opt(colors=True).exception(f'<yellow>{file_name}:{line}</yellow>(<blue>{thread_name}:{thread_count}</blue>) {tmp_args}')
     else:
-        # 将args转换为字符串
-        args = [str(arg) for arg in args]
-        # 将字符串拼接起来
-        args = " ".join(args)
-        logger.opt(colors=True).info(f'<yellow>{file_name}:{line}</yellow>(<blue>{thread_name}:{thread_count}</blue>) {args}')
+        # for arg in args:
+        #     logger.info(arg)
+        # # # 将args转换为字符串
+        # args = [str(arg) for arg in args]
+        # # # 将字符串拼接起来
+        # args = " ".join(args)
+        # 如果**kwargs中有end参数，则使用end参数的值，否则使用默认值\n
+        end = kwargs.get("end", " ")
+        # 将end格式添加到args中
+        final_str = ''
+        for arg in tmp_args:
+            try:
+                if isinstance(arg, (dict, tuple, list)):
+                    # 如果不是list，转换为list
+                    if not isinstance(arg, list):
+                        arg = list(arg.items())
+                    final_str = final_str + '\r\n' + tabulate(arg, maxcolwidths=30, tablefmt='grid', showindex=True, headers='keys') + end
+                else:
+                    final_str = final_str + str(arg) + end
+            except:
+                final_str = final_str + str(arg) + end
+        logger.opt(colors=True).info(f'<yellow>{file_name}:{line}</yellow>(<blue>{thread_name}:{thread_count}</blue>)\r\n{final_str}')
     
         
 # print = monky_print
\ No newline at end of file
